@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # coding=utf-8
 #
 # This file is part of the LibreOffice project.
@@ -18,13 +18,17 @@ import os
 import re
 import sys
 
+
 def usage():
     message = """Usage: {program} en-cs.txt blacklist.txt
 
   en-cs.txt:     Dictionary data from https://www.svobodneslovniky.cz/
   blacklist.txt: List of words that should be ignored when generating
 """
-    sys.stderr.write(message.format(program = os.path.basename(sys.argv[0])))
+    print(
+        message.format(program=os.path.basename(sys.argv[0])),
+        file=sys.stderr)
+
 
 def classify(typ):
     if typ == '':
@@ -40,6 +44,7 @@ def classify(typ):
 
     return ''
 
+
 def parse(filename, blacklistname):
     blacklist = {}
 
@@ -56,8 +61,8 @@ def parse(filename, blacklistname):
     meanings = {}
     classification = {}
 
-    match_ignore = re.compile('(\[neprav\.\]|\[vulg\.\])')
-    match_cleanup = re.compile('(\[.*\]|\*|:.*)')
+    match_ignore = re.compile(r'(\[neprav\.\]|\[vulg\.\])')
+    match_cleanup = re.compile(r'(\[.*\]|\*|:.*)')
 
     with open(filename, "r") as fp:
         for line in fp:
@@ -92,7 +97,7 @@ def parse(filename, blacklistname):
                     typ = terms[2]
 
                     # ignore non-translations
-                    if match_ignore.search(typ) != None:
+                    if match_ignore.search(typ) is not None:
                         continue
 
                     typ = match_cleanup.sub('', typ)
@@ -101,24 +106,25 @@ def parse(filename, blacklistname):
                 typ = classify(typ)
 
                 if index in synonyms:
-                    synonyms[index].append( (word, typ) )
+                    synonyms[index].append((word, typ))
                 else:
-                    synonyms[index] = [ (word, typ) ]
+                    synonyms[index] = [(word, typ)]
 
                 if word in meanings:
                     meanings[word].append(index)
                 else:
-                    meanings[word] = [ index ]
+                    meanings[word] = [index]
 
                 if typ != '':
                     if word in classification:
-                        if not typ in classification[word]:
+                        if typ not in classification[word]:
                             classification[word].append(typ)
                     else:
-                        classification[word] = [ typ ]
+                        classification[word] = [typ]
 
     return (synonyms, meanings, classification)
 
+
 def buildThesaurus(synonyms, meanings, classification):
     # for every word:
     #   find all the indexes, and then again map the indexes to words - these are the synonyms
@@ -133,7 +139,7 @@ def buildThesaurus(synonyms, meanings, classification):
             typ = classification[word][0]
 
         # we want to output each word just once
-        used_this_round = [ word ]
+        used_this_round = [word]
 
         output_lines = []
         for index in indexes:
@@ -142,7 +148,7 @@ def buildThesaurus(synonyms, meanings, classification):
             # collect types first
             types = []
             for (w, t) in syns:
-                if not t in types:
+                if t not in types:
                     types.append(t)
 
             # build the various thesaurus lines
@@ -153,7 +159,7 @@ def buildThesaurus(synonyms, meanings, classification):
                 if typ != '' and t != '' and typ != t:
                     continue
 
-                if not w in used_this_round:
+                if w not in used_this_round:
                     if t in line:
                         line[t] += '|' + w
                     else:
@@ -163,10 +169,10 @@ def buildThesaurus(synonyms, meanings, classification):
             if len(line) != 0:
                 for t in types:
                     if t in line:
-                        output_lines.append( (t, line[t]) )
+                        output_lines.append((t, line[t]))
 
         if len(output_lines) > 0:
-            print word + '|' + str(len(output_lines))
+            print(word + '|' + str(len(output_lines)))
 
             # those with existing classification are probably a better fit,
             # put them to the front (even if we don't output the
@@ -176,9 +182,10 @@ def buildThesaurus(synonyms, meanings, classification):
                     # first pass only non-empty, 2nd pass only empty
                     if (i == 0 and t != '') or (i == 1 and t == ''):
                         if typ == '':
-                            print t + line
+                            print(t + line)
                         else:
-                            print line
+                            print(line)
+
 
 def main(args):
     if (len(args) != 3):
@@ -187,9 +194,10 @@ def main(args):
 
     (synonyms, meanings, classification) = parse(args[1], args[2])
 
-    print "UTF-8"
+    print("UTF-8")
     buildThesaurus(synonyms, meanings, classification)
 
+
 if __name__ == "__main__":
     main(sys.argv)
 
